@@ -1,6 +1,6 @@
-""" Command to improve code quality """
+""" Improve code quality """
 
-from typing import Annotated
+from typing import Annotated, Optional
 import typer
 from huggingface_hub import InferenceClient
 from rich import print
@@ -14,9 +14,18 @@ def enhance(
             help="File containing code to enhance for quality improvements."
         ),
     ],
+    output: Annotated[
+        Optional[typer.FileTextWrite],
+        typer.Option(
+            "--output",
+            "-o",
+            help="Output file to write the response to.",
+            encoding="utf-8",
+        ),
+    ] = None,
 ) -> None:
     """
-    Improve code quality by applying best practices.
+    Improve code quality by applying best practices and enhancements suggested by CodeStar.
 
     Args:
         code (typer.FileText): The file containing code to be enhanced.
@@ -24,6 +33,7 @@ def enhance(
     Examples:
     ```shell
     code-star enhance code.py
+    code-star enhance code.py -o code-enhancements.md
     ```
     """
 
@@ -46,7 +56,14 @@ def enhance(
             max_tokens=2048,
         )
 
-        print_highlighted(response.choices[0].message.content)
+        if output:
+            with output as file:
+                file.write(response.choices[0].message.content)
+
+            print(f"Output [bold green]saved[/bold green] to {output.name}.")
+
+        else:
+            print_highlighted(response.choices[0].message.content)
 
     except Exception as error:
         print(f"[bold red]Error[/bold red]: {error}")
