@@ -1,6 +1,6 @@
-""" Command to perform code scanning """
+""" Perform code scanning """
 
-from typing import Annotated
+from typing import Annotated, Optional
 import typer
 from huggingface_hub import InferenceClient
 from rich import print
@@ -12,9 +12,18 @@ def scan(
         typer.FileText,
         typer.Argument(help="File containing code to scan for vulnerabilities."),
     ],
+    output: Annotated[
+        Optional[typer.FileTextWrite],
+        typer.Option(
+            "--output",
+            "-o",
+            help="Output file to write the response to.",
+            encoding="utf-8",
+        ),
+    ] = None,
 ) -> None:
     """
-    Scan the provided code for security vulnerabilities.
+    Scan the provided code for security vulnerabilities to provide suggestions on how to improve it.
 
     Args:
         code (typer.FileText): The file containing code to be scanned.
@@ -22,6 +31,7 @@ def scan(
     Examples:
     ```shell
     code-star scan code.py
+    code-star scan code.py -o code-scan.md
     ```
     """
 
@@ -40,10 +50,17 @@ def scan(
                     f"\n{code.read()}",
                 },
             ],
-            max_tokens=1024,
+            max_tokens=2048,
         )
 
-        print_highlighted(response.choices[0].message.content)
+        if output:
+            with output as file:
+                file.write(response.choices[0].message.content)
+
+            print(f"Output [bold green]saved[/bold green] to {output.name}.")
+
+        else:
+            print_highlighted(response.choices[0].message.content)
 
     except Exception as error:
         print(f"[bold red]Error[/bold red]: {error}")
